@@ -6,7 +6,17 @@ from __future__ import annotations
 
 from bisect import bisect
 from copy import copy
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Tuple, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+)
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -19,7 +29,7 @@ from .._logging import logger
 from .._units import Quantity
 from .._units import units as plonk_units
 from ..utils.math import average
-from ..utils.utils import is_documented_by, pretty_array_name
+from ..utils.strings import is_documented_by, pretty_array_name
 from ._profiles import extra_profiles
 
 if TYPE_CHECKING:
@@ -138,6 +148,7 @@ class Profile:
 
         self.bin_edges, self['size'] = self._setup_bins()
         self.bin_centers = 0.5 * (self.bin_edges[:-1] + self.bin_edges[1:])
+        self._x = self._x.to(self.bin_edges.units)
         self._particle_bin = np.digitize(self._x.magnitude, self.bin_edges.magnitude)
         self.bin_indicies = self._set_particle_bin_indicies()
 
@@ -286,8 +297,7 @@ class Profile:
             'Requested profile has array dimension > 1.\nTo access x-, y-, or '
             'z-components, or magnitude of vector quantities,\ntry, for '
             'example, prof["velocity_x"] or prof["momentum_mag"].\nTo '
-            'access dust profiles, try, for example, prof["stopping_time_001"] '
-            'or\nprof["dust_mass_tot"].'
+            'access dust profiles, try, for example, prof["stopping_time_001"]'
         )
 
     def __getitem__(self, name: str) -> Quantity:
@@ -374,8 +384,8 @@ class Profile:
 
         return self
 
-    def base_array_name(self, name: str) -> str:
-        """Get the base array name from a string.
+    def base_profile_name(self, name: str) -> str:
+        """Get the base profile name from a string.
 
         For example, 'velocity_x' returns 'velocity', 'density' returns
         'density', 'dust_fraction_001' returns 'dust_fraction', 'x'
@@ -396,6 +406,16 @@ class Profile:
         except ValueError:
             if name == self._coordinate:
                 return 'position'
+            name_root = '_'.join(name.split('_')[:-1])
+            name_suffix = name.split('_')[-1]
+            if name_root == '' and name_suffix in ('x', 'y', 'z'):
+                return 'position'
+            if name_root in self.snap._array_aliases:
+                return self.snap._array_aliases[name_root]
+            if name_suffix in ('x', 'y', 'z', 'mag'):
+                return name_root
+            if _str_is_int(name_suffix):
+                return name_root
             return name
 
     def plot(
@@ -404,6 +424,7 @@ class Profile:
         y: Union[str, List[str]],
         units: Dict[str, Union[str, List[str]]] = None,
         std: str = None,
+        label: Union[str, List[str]] = None,
         ax: Any = None,
         ax_kwargs={},
         **kwargs,
@@ -415,16 +436,18 @@ class Profile:
         x
             The x axis to plot as a string.
         y
-            The y axis to plot. Can be string or multiple as a list of
-            strings.
+            The y axis to plot. Can be string or a list of strings.
         units
-            The units of the plot as a dictionary. The keys correspond to
-            quantities such as 'position', 'density', 'velocity', and so on.
-            The values are strings representing units, e.g. 'g/cm^3' for
-            density.
-        std: optional
+            The units of the plot as a dictionary. The keys correspond
+            to quantities such as 'position', 'density', 'velocity', and
+            so on. The values are strings representing units, e.g.
+            'g/cm^3' for density.
+        std : optional
             Add standard deviation on profile. Can be 'shading' or
             'errorbar'.
+        label : optional
+            A label for the plot. Can be a string or a list of strings,
+            one per y.
         ax : optional
             A matplotlib Axes object to plot to.
         ax_kwargs
@@ -437,34 +460,41 @@ class Profile:
         ax
             The matplotlib Axes object.
         """
-        if std is not None:
-            if std not in ('shading', 'errorbar'):
-                raise ValueError('std must be "shading" or "errorbar"')
+        if std is not None and std not in ('shading', 'errorbar'):
+            raise ValueError('std must be "shading" or "errorbar"')
 
         if ax is None:
             _, ax = plt.subplots()
 
         if isinstance(y, str):
-            y = [y]
+            ynames = [y]
+        else:
+            ynames = y
 
-        x_unit = _get_unit(self, x, units)
-        y_unit = [_get_unit(self, yi, units) for yi in y]
-
-        xdata = self[x].to(x_unit)
-
-        xlabel = pretty_array_name(x)
-        ax.set_xlabel(f'{xlabel} [{xdata.units:~P}]')
-
-        for idx, yname in enumerate(y):
-            ydata = self[yname].to(y_unit[idx])
-            ylabel = pretty_array_name(yname)
-            label = f'{ylabel} [{ydata.units:~P}]'
-            if kwargs.get('label') is None:
-                ax.plot(xdata.magnitude, ydata.magnitude, label=label, **kwargs)
+        labels: Sequence[Optional[str]]
+        if label is not None:
+            if isinstance(label, str):
+                labels = [label]
             else:
-                ax.plot(xdata.magnitude, ydata.magnitude, **kwargs)
+                labels = label
+        else:
+            labels = [None for _ in ynames]
+
+        xunit = _get_unit(self, x, units)
+        yunits = [_get_unit(self, y, units) for y in ynames]
+
+        xdata = self[x].to(xunit)
+
+        for yname, yunit, label in zip(ynames, yunits, labels):
+            ydata = self[yname].to(yunit)
+            if label is None:
+                label = f'{pretty_array_name(yname)} [{ydata.units:~P}]'
+            [line] = ax.plot(xdata.magnitude, ydata.magnitude, label=label, **kwargs)
             if std:
-                _std_plot(self, xdata, ydata, yname, y_unit[idx], std, ax)
+                color = line.get_color()
+                _std_plot(self, xdata, ydata, yname, yunit, std, color, ax)
+
+        ax.set_xlabel(f'{pretty_array_name(x)} [{xdata.units:~P}]')
         ax.legend()
         ax.set(**ax_kwargs)
 
@@ -580,27 +610,25 @@ class Profile:
         if aggregation not in _aggregations:
             raise ValueError('Cannot determine aggregation method')
 
-        binned_quantity = np.zeros(self.n_bins)
+        _array = array[self._mask]
+        binned_quantity = np.zeros(self.n_bins) * _array.units
         for idx, bin_ind in enumerate(self.bin_indicies):
             if bin_ind.size == 0:
                 continue
             if aggregation == 'average':
                 val = average(
-                    array[self._mask][bin_ind],
-                    weights=self._weights[self._mask][bin_ind],
+                    _array[bin_ind], weights=self._weights[self._mask][bin_ind],
                 )
             elif aggregation == 'mean':
-                val = np.mean(array[self._mask][bin_ind])
+                val = np.mean(_array[bin_ind])
             elif aggregation == 'median':
-                val = np.median(array[self._mask][bin_ind])
+                val = np.median(_array[bin_ind])
             elif aggregation == 'std':
-                val = np.std(array[self._mask][bin_ind])
+                val = np.std(_array[bin_ind])
             elif aggregation == 'sum':
-                val = np.sum(array[self._mask][bin_ind])
+                val = np.sum(_array[bin_ind])
 
-            binned_quantity[idx] = val.magnitude
-
-        binned_quantity *= val.units
+            binned_quantity[idx] = val
 
         return binned_quantity
 
@@ -660,18 +688,20 @@ def _1d_arrays(arrays: list) -> list:
 def _get_unit(profile, name, units):
     if name is None:
         return None
-    base_name = profile.base_array_name(name)
+    base_name = profile.base_profile_name(name)
     if units is not None:
         if name in units:
             return 1 * plonk_units(units[name])
         if base_name in units:
             return 1 * plonk_units(units[base_name])
+    if name in profile.default_units:
+        return 1 * plonk_units(profile.default_units[name])
     if base_name in profile.default_units:
         return 1 * plonk_units(profile.default_units[base_name])
-    return 1 * profile[base_name].units
+    return 1 * profile[name].units
 
 
-def _std_plot(profile, xdata, ydata, yname, yunit, std, ax):
+def _std_plot(profile, xdata, ydata, yname, yunit, std, color, ax):
     if yname.split('_')[-1] in _aggregations:
         _yname = '_'.join(yname.split('_')[:-1])
     else:
@@ -687,7 +717,6 @@ def _std_plot(profile, xdata, ydata, yname, yunit, std, ax):
         y_mean = ydata
     y_std = y_std.to(yunit).magnitude
     y_mean = y_mean.to(yunit).magnitude
-    color = ax.lines[0].get_color()
     xdata = xdata.magnitude
     if std == 'shading':
         ax.fill_between(
@@ -695,3 +724,11 @@ def _std_plot(profile, xdata, ydata, yname, yunit, std, ax):
         )
     elif std == 'errorbar':
         ax.errorbar(xdata, y_mean, yerr=y_std, linestyle='', color=color, alpha=0.5)
+
+
+def _str_is_int(string: str) -> bool:
+    try:
+        int(string)
+        return True
+    except ValueError:
+        return False
