@@ -6,13 +6,11 @@ snapshot file.
 
 from .readers import load_snap
 from .snap import Sinks, Snap, SnapLike, SubSnap
-from .utils import gravitational_constant_in_code_units
 
 __all__ = [
     'Sinks',
     'Snap',
     'SnapLike',
     'SubSnap',
-    'gravitational_constant_in_code_units',
     'load_snap',
 ]
