@@ -38,6 +38,7 @@ AVAILABLE_ARRAYS = [
     'smoothing_length',
     'sound_speed',
     'specific_angular_momentum',
+    'specific_kinetic_energy',
     'stokes_number',
     'stopping_time',
     'sub_type',
@@ -130,7 +131,7 @@ def test_available_loaded_arrays():
         'position_z',
         'position_mag',
         'h',
-        'dust_to_gas_ratio_tot',
+        'dust_to_gas_ratio',
     ]:
         snap[arr]
 
